function varargout = MyTime(varargin)
% MYTIME M-file for MyTime.fig
%      MYTIME, by itself, creates a new MYTIME or raises the existing
%      singleton*.
%
%      H = MYTIME returns the handle to a new MYTIME or the handle to
%      the existing singleton*.
%
%      MYTIME('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in MYTIME.M with the given input arguments.
%
%      MYTIME('Property','Value',...) creates a new MYTIME or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before MyTime_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to MyTime_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help MyTime

% Last Modified by GUIDE v2.5 03-Mar-2010 14:55:07

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @MyTime_OpeningFcn, ...
                   'gui_OutputFcn',  @MyTime_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before MyTime is made visible.
function MyTime_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to MyTime (see VARARGIN)

% Choose default command line output for MyTime
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes MyTime wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = MyTime_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in timebutton.
function timebutton_Callback(hObject, eventdata, handles)
% hObject    handle to timebutton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
d = clock;
time = sprintf('%2d:%2d:%2d', d(4), d(5), d(6));
set(gcbo, 'String', time)
